@@ -4,7 +4,9 @@
 
 CSms * CSms::m_self = 0;
 
+#ifndef NOSMS
 QTM_USE_NAMESPACE
+#endif
 
 CSms::CSms(QObject * parent)
 : IRdsText(parent)
@@ -54,6 +56,7 @@ int CSms::getTimeout()
 void CSms::setEnable(bool value)
 {
     if (value) {
+#ifndef NOSMS
         messageManager = new QMessageManager(this);
         connect(messageManager, SIGNAL(messageAdded(QMessageId,QMessageManager::NotificationFilterIdSet)), this, SLOT(slotMessageAdded(QMessageId,QMessageManager::NotificationFilterIdSet)));
         // - SMS filter
@@ -61,8 +64,11 @@ void CSms::setEnable(bool value)
         m_notifFilterSet.insert(messageManager->registerNotificationFilter(
             QMessageFilter::byType(QMessage::Sms) &
             QMessageFilter::byStandardFolder(QMessage::InboxFolder)));
+#endif
     } else {
+#ifndef NOSMS
         delete messageManager;
+#endif
     }
     state = value;
     qDebug() << "Connected is " << value;
@@ -90,18 +96,21 @@ void CSms::setConnect(int value)
     if (value)
         setEnable(state);
     else {
+#ifndef NOSMS
         delete messageManager;
+#endif
     }
     bConnect = value;
 }
-
+#ifndef NOSMS
 void CSms::slotMessageAdded(QMessageId Id, QMessageManager::NotificationFilterIdSet Filter)
 {
+
     if (Filter.contains(m_notifFilterSet)) {
         QMessage message(Id)    ;
         QString msg = QString("%1 %2").arg(message.from().addressee()).arg(message.textContent());
         sendText( msg);
         qDebug() << msg;
     }
-
 }
+#endif
