@@ -3,15 +3,15 @@
 
 #include "IRdsText.h"
 #include <QtDBus>
+
+#ifndef NOSMS
 #include <QMessageManager>
-
-
 QTM_BEGIN_NAMESPACE
-class QMessag;
-class QGeoPositionInfoSource;
+class QMessageManager;
 QTM_END_NAMESPACE
 
 QTM_USE_NAMESPACE
+#endif
 
 class CSms : public IRdsText
 {
@@ -55,11 +55,13 @@ private:
     bool state;
     // Tx connect state
     bool bConnect;
+#ifndef NOSMS
     QMessageManager *messageManager;
     QMessageManager::NotificationFilterIdSet m_notifFilterSet;
 
 private slots:
     void slotMessageAdded(QMessageId,QMessageManager::NotificationFilterIdSet);
+#endif
 };
 
 #endif // CSMS_H
